# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metering.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import attestation_pb2 as attestation__pb2
from . import data_room_pb2 as data__room__pb2
from . import integrity_store_pb2 as integrity__store__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emetering.proto\x12\x08metering\x1a\x11\x61ttestation.proto\x1a\x0f\x64\x61ta_room.proto\x1a\x15integrity_store.proto\"[\n\x0b\x45nclaveInfo\x12\x1e\n\x16\x61ttestationSpecHashHex\x18\x01 \x01(\t\x12\x1a\n\rtaskQueueName\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_taskQueueName\"\xb3\x07\n\x0fMeteringRequest\x12/\n\tcreateDcr\x18\x01 \x01(\x0b\x32\x1a.metering.CreateDcrRequestH\x00\x12;\n\x0f\x63reateDcrCommit\x18\x02 \x01(\x0b\x32 .metering.CreateDcrCommitRequestH\x00\x12+\n\x07stopDcr\x18\x03 \x01(\x0b\x32\x18.metering.StopDcrRequestH\x00\x12\x39\n\x0epublishDataset\x18\x04 \x01(\x0b\x32\x1f.metering.PublishDatasetRequestH\x00\x12=\n\x10unpublishDataset\x18\x05 \x01(\x0b\x32!.metering.UnpublishDatasetRequestH\x00\x12\x39\n\x0eworkerMetadata\x18\x06 \x01(\x0b\x32\x1f.metering.WorkerMetadataRequestH\x00\x12O\n\x19submitWorkerExecutionTime\x18\x07 \x01(\x0b\x32*.metering.SubmitWorkerExecutionTimeRequestH\x00\x12\x39\n\x0e\x64\x63rInteraction\x18\x08 \x01(\x0b\x32\x1f.metering.DcrInteractionRequestH\x00\x12\x37\n\rcreateDataset\x18\t \x01(\x0b\x32\x1e.metering.CreateDatasetRequestH\x00\x12K\n\x17getOrCreateDatasetScope\x18\n \x01(\x0b\x32(.metering.GetOrCreateDatasetScopeRequestH\x00\x12\x39\n\x0emergeDcrCommit\x18\x0b \x01(\x0b\x32\x1f.metering.MergeDcrCommitRequestH\x00\x12S\n\x1bgetDataConnectorCredentials\x18\x0c \x01(\x0b\x32,.metering.GetDataConnectorCredentialsRequestH\x00\x12\x44\n\x0eintegrityStore\x18\r \x01(\x0b\x32*.integrity_store_api.IntegrityStoreRequestH\x00\x12]\n getAzureCommunicationCredentials\x18\x0e \x01(\x0b\x32\x31.metering.GetAzureCommunicationCredentialsRequestH\x00\x42\t\n\x07request\"\xc7\x07\n\x17MeteringSuccessResponse\x12\x30\n\tcreateDcr\x18\x01 \x01(\x0b\x32\x1b.metering.CreateDcrResponseH\x00\x12<\n\x0f\x63reateDcrCommit\x18\x02 \x01(\x0b\x32!.metering.CreateDcrCommitResponseH\x00\x12,\n\x07stopDcr\x18\x03 \x01(\x0b\x32\x19.metering.StopDcrResponseH\x00\x12:\n\x0epublishDataset\x18\x04 \x01(\x0b\x32 .metering.PublishDatasetResponseH\x00\x12>\n\x10unpublishDataset\x18\x05 \x01(\x0b\x32\".metering.UnpublishDatasetResponseH\x00\x12:\n\x0eworkerMetadata\x18\x06 \x01(\x0b\x32 .metering.WorkerMetadataResponseH\x00\x12P\n\x19submitWorkerExecutionTime\x18\x07 \x01(\x0b\x32+.metering.SubmitWorkerExecutionTimeResponseH\x00\x12:\n\x0e\x64\x63rInteraction\x18\x08 \x01(\x0b\x32 .metering.DcrInteractionResponseH\x00\x12\x38\n\rcreateDataset\x18\t \x01(\x0b\x32\x1f.metering.CreateDatasetResponseH\x00\x12L\n\x17getOrCreateDatasetScope\x18\n \x01(\x0b\x32).metering.GetOrCreateDatasetScopeResponseH\x00\x12:\n\x0emergeDcrCommit\x18\x0b \x01(\x0b\x32 .metering.MergeDcrCommitResponseH\x00\x12Q\n\x18\x64\x61taConnectorCredentials\x18\x0c \x01(\x0b\x32-.metering.GetDataConnectorCredentialsResponseH\x00\x12\x45\n\x0eintegrityStore\x18\r \x01(\x0b\x32+.integrity_store_api.IntegrityStoreResponseH\x00\x12^\n getAzureCommunicationCredentials\x18\x0e \x01(\x0b\x32\x32.metering.GetAzureCommunicationCredentialsResponseH\x00\x42\n\n\x08response\"g\n\x10MeteringResponse\x12\x34\n\x07success\x18\x01 \x01(\x0b\x32!.metering.MeteringSuccessResponseH\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"\x98\x01\n\x0b\x44\x63rMetadata\x12+\n\x07purpose\x18\x01 \x01(\x0e\x32\x1a.metering.CreateDcrPurpose\x12\x1c\n\x14showOrganizationLogo\x18\x02 \x01(\x08\x12\x17\n\x0frequirePassword\x18\x03 \x01(\x08\x12%\n\x04kind\x18\x04 \x01(\x0e\x32\x17.metering.CreateDcrKind\"\xb9\x01\n\x10\x43reateDcrRequest\x12\r\n\x05idHex\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12\x19\n\x11participantEmails\x18\x04 \x03(\t\x12\x15\n\x08metadata\x18\x05 \x01(\x0cH\x00\x88\x01\x01\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfoB\x0b\n\t_metadata\"~\n!ExecuteComputationNodeInteraction\x12\x0e\n\x06nodeId\x18\x01 \x01(\t\x12\x38\n\x0crateLimiting\x18\x02 \x01(\x0b\x32\x1d.data_room.RateLimitingConfigH\x00\x88\x01\x01\x42\x0f\n\r_rateLimiting\"[\n\x1d\x45xecuteComputationInteraction\x12:\n\x05nodes\x18\x01 \x03(\x0b\x32+.metering.ExecuteComputationNodeInteraction\"v\n\x19PublishDatasetInteraction\x12\x0e\n\x06nodeId\x18\x01 \x01(\t\x12\x38\n\x0crateLimiting\x18\x02 \x01(\x0b\x32\x1d.data_room.RateLimitingConfigH\x00\x88\x01\x01\x42\x0f\n\r_rateLimiting\"\xa2\x01\n\x12\x44\x63rInteractionKind\x12\x45\n\x12\x65xecuteComputation\x18\x01 \x01(\x0b\x32\'.metering.ExecuteComputationInteractionH\x00\x12=\n\x0epublishDataset\x18\x02 \x01(\x0b\x32#.metering.PublishDatasetInteractionH\x00\x42\x06\n\x04kind\"\x90\x01\n\x15\x44\x63rInteractionRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x02 \x01(\t\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\x12\x31\n\x0binteraction\x18\x04 \x01(\x0b\x32\x1c.metering.DcrInteractionKind\"y\n\x15PublishDatasetRequest\x12\x15\n\rcomputeNodeId\x18\x01 \x01(\t\x12\x14\n\x0cmanifestHash\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taRoomHash\x18\x03 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x04 \x01(\t\"\x99\x02\n\x14\x43reateDatasetRequest\x12\x14\n\x0cmanifestHash\x18\x01 \x01(\t\x12\x15\n\x08manifest\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tsizeBytes\x18\x06 \x01(\x04H\x02\x88\x01\x01\x12\x17\n\nstatistics\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0f\x64\x61tasetImportId\x18\x08 \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_manifestB\x0e\n\x0c_descriptionB\x0c\n\n_sizeBytesB\r\n\x0b_statisticsB\x12\n\x10_datasetImportId\"L\n\x1eGetOrCreateDatasetScopeRequest\x12\x19\n\x0cmanifestHash\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_manifestHash\"e\n\x17UnpublishDatasetRequest\x12\x15\n\rcomputeNodeId\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61taRoomHash\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\"E\n\x0eStopDcrRequest\x12\x14\n\x0c\x64\x61taRoomHash\x18\x01 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x02 \x01(\t\"\x81\x01\n\x16\x43reateDcrCommitRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x63rIdHex\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfo\"\x80\x01\n\x15MergeDcrCommitRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x63rIdHex\x18\x02 \x01(\t\x12\x1d\n\x15\x64riverAttestationHash\x18\x03 \x01(\t\x12*\n\x0b\x65nclaveInfo\x18\x06 \x03(\x0b\x32\x15.metering.EnclaveInfo\"\x13\n\x11\x43reateDcrResponse\"-\n\x1fGetOrCreateDatasetScopeResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x16\x44\x63rInteractionResponse\"\x19\n\x17\x43reateDcrCommitResponse\"\x18\n\x16MergeDcrCommitResponse\"\x11\n\x0fStopDcrResponse\"\x18\n\x16PublishDatasetResponse\"#\n\x15\x43reateDatasetResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18UnpublishDatasetResponse\"h\n\x15WorkerMetadataRequest\x12>\n\x0f\x61ttestationSpec\x18\x01 \x01(\x0b\x32%.attestation.AttestationSpecification\x12\x0f\n\x07scopeId\x18\x02 \x01(\t\"5\n\x16WorkerMetadataResponse\x12\x1b\n\x13maxExecutionSeconds\x18\x01 \x01(\x04\"\x91\x01\n SubmitWorkerExecutionTimeRequest\x12\x1c\n\x14\x65xecutionTimeSeconds\x18\x01 \x01(\r\x12>\n\x0f\x61ttestationSpec\x18\x02 \x01(\x0b\x32%.attestation.AttestationSpecification\x12\x0f\n\x07scopeId\x18\x03 \x01(\t\"#\n!SubmitWorkerExecutionTimeResponse\"\x14\n\x12SplickyCredentials\"$\n\x12MicrosoftDspMember\x12\x0e\n\x06member\x18\x01 \x01(\t\"\x8d\x01\n\x0f\x43redentialsKind\x12/\n\x07splicky\x18\x01 \x01(\x0b\x32\x1c.metering.SplickyCredentialsH\x00\x12:\n\x12microsoftDspMember\x18\x02 \x01(\x0b\x32\x1c.metering.MicrosoftDspMemberH\x00\x42\r\n\x0b\x63redentials\"M\n\"GetDataConnectorCredentialsRequest\x12\'\n\x04kind\x18\x01 \x01(\x0b\x32\x19.metering.CredentialsKind\":\n#GetDataConnectorCredentialsResponse\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\")\n\'GetAzureCommunicationCredentialsRequest\"d\n(GetAzureCommunicationCredentialsResponse\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x11\n\taccessKey\x18\x02 \x01(\t\x12\x13\n\x0bsenderEmail\x18\x03 \x01(\t*`\n\x10\x43reateDcrPurpose\x12\x0c\n\x08STANDARD\x10\x00\x12\x0e\n\nVALIDATION\x10\x01\x12\x0f\n\x0b\x44\x41TA_IMPORT\x10\x02\x12\x0f\n\x0b\x44\x41TA_EXPORT\x10\x03\x12\x0c\n\x08\x44\x41TA_LAB\x10\x04*n\n\rCreateDcrKind\x12\n\n\x06\x45XPERT\x10\x00\x12\x0f\n\x0b\x44\x41TASCIENCE\x10\x01\x12\t\n\x05MEDIA\x10\x02\x12\x13\n\x0fLOOKALIKE_MEDIA\x10\x03\x12\x12\n\x0eMEDIA_INSIGHTS\x10\x04\x12\x0c\n\x08\x41\x42_MEDIA\x10\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metering_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CREATEDCRPURPOSE']._serialized_start=5214
  _globals['_CREATEDCRPURPOSE']._serialized_end=5310
  _globals['_CREATEDCRKIND']._serialized_start=5312
  _globals['_CREATEDCRKIND']._serialized_end=5422
  _globals['_ENCLAVEINFO']._serialized_start=87
  _globals['_ENCLAVEINFO']._serialized_end=178
  _globals['_METERINGREQUEST']._serialized_start=181
  _globals['_METERINGREQUEST']._serialized_end=1128
  _globals['_METERINGSUCCESSRESPONSE']._serialized_start=1131
  _globals['_METERINGSUCCESSRESPONSE']._serialized_end=2098
  _globals['_METERINGRESPONSE']._serialized_start=2100
  _globals['_METERINGRESPONSE']._serialized_end=2203
  _globals['_DCRMETADATA']._serialized_start=2206
  _globals['_DCRMETADATA']._serialized_end=2358
  _globals['_CREATEDCRREQUEST']._serialized_start=2361
  _globals['_CREATEDCRREQUEST']._serialized_end=2546
  _globals['_EXECUTECOMPUTATIONNODEINTERACTION']._serialized_start=2548
  _globals['_EXECUTECOMPUTATIONNODEINTERACTION']._serialized_end=2674
  _globals['_EXECUTECOMPUTATIONINTERACTION']._serialized_start=2676
  _globals['_EXECUTECOMPUTATIONINTERACTION']._serialized_end=2767
  _globals['_PUBLISHDATASETINTERACTION']._serialized_start=2769
  _globals['_PUBLISHDATASETINTERACTION']._serialized_end=2887
  _globals['_DCRINTERACTIONKIND']._serialized_start=2890
  _globals['_DCRINTERACTIONKIND']._serialized_end=3052
  _globals['_DCRINTERACTIONREQUEST']._serialized_start=3055
  _globals['_DCRINTERACTIONREQUEST']._serialized_end=3199
  _globals['_PUBLISHDATASETREQUEST']._serialized_start=3201
  _globals['_PUBLISHDATASETREQUEST']._serialized_end=3322
  _globals['_CREATEDATASETREQUEST']._serialized_start=3325
  _globals['_CREATEDATASETREQUEST']._serialized_end=3606
  _globals['_GETORCREATEDATASETSCOPEREQUEST']._serialized_start=3608
  _globals['_GETORCREATEDATASETSCOPEREQUEST']._serialized_end=3684
  _globals['_UNPUBLISHDATASETREQUEST']._serialized_start=3686
  _globals['_UNPUBLISHDATASETREQUEST']._serialized_end=3787
  _globals['_STOPDCRREQUEST']._serialized_start=3789
  _globals['_STOPDCRREQUEST']._serialized_end=3858
  _globals['_CREATEDCRCOMMITREQUEST']._serialized_start=3861
  _globals['_CREATEDCRCOMMITREQUEST']._serialized_end=3990
  _globals['_MERGEDCRCOMMITREQUEST']._serialized_start=3993
  _globals['_MERGEDCRCOMMITREQUEST']._serialized_end=4121
  _globals['_CREATEDCRRESPONSE']._serialized_start=4123
  _globals['_CREATEDCRRESPONSE']._serialized_end=4142
  _globals['_GETORCREATEDATASETSCOPERESPONSE']._serialized_start=4144
  _globals['_GETORCREATEDATASETSCOPERESPONSE']._serialized_end=4189
  _globals['_DCRINTERACTIONRESPONSE']._serialized_start=4191
  _globals['_DCRINTERACTIONRESPONSE']._serialized_end=4215
  _globals['_CREATEDCRCOMMITRESPONSE']._serialized_start=4217
  _globals['_CREATEDCRCOMMITRESPONSE']._serialized_end=4242
  _globals['_MERGEDCRCOMMITRESPONSE']._serialized_start=4244
  _globals['_MERGEDCRCOMMITRESPONSE']._serialized_end=4268
  _globals['_STOPDCRRESPONSE']._serialized_start=4270
  _globals['_STOPDCRRESPONSE']._serialized_end=4287
  _globals['_PUBLISHDATASETRESPONSE']._serialized_start=4289
  _globals['_PUBLISHDATASETRESPONSE']._serialized_end=4313
  _globals['_CREATEDATASETRESPONSE']._serialized_start=4315
  _globals['_CREATEDATASETRESPONSE']._serialized_end=4350
  _globals['_UNPUBLISHDATASETRESPONSE']._serialized_start=4352
  _globals['_UNPUBLISHDATASETRESPONSE']._serialized_end=4378
  _globals['_WORKERMETADATAREQUEST']._serialized_start=4380
  _globals['_WORKERMETADATAREQUEST']._serialized_end=4484
  _globals['_WORKERMETADATARESPONSE']._serialized_start=4486
  _globals['_WORKERMETADATARESPONSE']._serialized_end=4539
  _globals['_SUBMITWORKEREXECUTIONTIMEREQUEST']._serialized_start=4542
  _globals['_SUBMITWORKEREXECUTIONTIMEREQUEST']._serialized_end=4687
  _globals['_SUBMITWORKEREXECUTIONTIMERESPONSE']._serialized_start=4689
  _globals['_SUBMITWORKEREXECUTIONTIMERESPONSE']._serialized_end=4724
  _globals['_SPLICKYCREDENTIALS']._serialized_start=4726
  _globals['_SPLICKYCREDENTIALS']._serialized_end=4746
  _globals['_MICROSOFTDSPMEMBER']._serialized_start=4748
  _globals['_MICROSOFTDSPMEMBER']._serialized_end=4784
  _globals['_CREDENTIALSKIND']._serialized_start=4787
  _globals['_CREDENTIALSKIND']._serialized_end=4928
  _globals['_GETDATACONNECTORCREDENTIALSREQUEST']._serialized_start=4930
  _globals['_GETDATACONNECTORCREDENTIALSREQUEST']._serialized_end=5007
  _globals['_GETDATACONNECTORCREDENTIALSRESPONSE']._serialized_start=5009
  _globals['_GETDATACONNECTORCREDENTIALSRESPONSE']._serialized_end=5067
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSREQUEST']._serialized_start=5069
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSREQUEST']._serialized_end=5110
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSRESPONSE']._serialized_start=5112
  _globals['_GETAZURECOMMUNICATIONCREDENTIALSRESPONSE']._serialized_end=5212
# @@protoc_insertion_point(module_scope)
